function dist_baker

Npts = 100000; Niter = 100; % number of initial points and iterates
alpha = .3; beta = 1-alpha;

% The large-deviation form of the PDF.
mh = @(h) (h + log(beta))/(log(beta/alpha));
G = @(h) mh(h).*log(mh(h)) + (1-mh(h)).*log(1-mh(h)) ...
    + mh(h)*log(beta/alpha) - log(beta);
sigma2 = alpha*beta*log(alpha/beta)^2;
Pld = @(h,n) sqrt(n/2/pi/sigma2) * exp(-n*G(h));

% Specify which 4 values of iterate n to plot.
plotn = [20 50 75 100]; plotgeom = [2 2]; nplot = 0;
% Generate random initial conditions.
rng('default'); X = rand(Npts,2);
lstr = zeros(Npts,1); % the log-stretch
for n = 1:Niter
  [X,str] = baker(X,alpha);  % apply baker's map (vectorized)
  lstr = lstr + log(str);
  if any(plotn == n)
    % Plot the results.
    nplot = nplot + 1; subplot(plotgeom(1),plotgeom(2),nplot)
    % Histogram of average stretching, normalized.
    [P,bins] = hist(lstr/n,20); P = P/trapz(bins,P);
    semilogy(bins,P,'b','LineWidth',1.5), hold on
    semilogy(bins,Pld(bins,n),'r--','LineWidth',2), hold off
    xlabel('$h$','Interpreter','LaTeX')
    ylabel('$\rho_{n}(h)$','Interpreter','LaTeX')
    axis([.35 1.05 2e-4 2e1])
    title(sprintf('$n = %d$',n),'Interpreter','LaTeX')
  end
end
print -dpdf dist_baker.pdf
